2014.7.13 2014-07-13
==============
----

* Introduce ``config`` module.
* Move constant variables from ``initializer`` to ``config`` module.
* Raise exception if currency does not exist.
* Add Usage examples to ``README.rst``.
* Add Tests section to ``README.rst``


2014.7.12 2014-07-12
==============
----

* Support many currencies.
* Full test suit.
* %100 test coverage.
* Initial release.
